@@ -3,6 +3,7 @@
 http://bionetgen.org/index.php/Simple
 """
 
+from __future__ import print_function
 from pysb import *
 
 Model()
@@ -32,7 +33,7 @@ Initial(EGF(R=None), EGF0)
 Initial(EGFR(L=None, CR1=None, Y1068='U'), EGFR0)
 
 
-Rule('egf_binds_egfr', EGF(R=None) + EGFR(L=None) <> EGF(R=1) % EGFR(L=1), kp1, km1)
+Rule('egf_binds_egfr', EGF(R=None) + EGFR(L=None) | EGF(R=1) % EGFR(L=1), kp1, km1)
 
 
 # Species LR EGF(R!1).EGFR(L!1)
@@ -40,7 +41,8 @@ Observable('Lbound', EGF(R=ANY))  # Molecules
 
 
 if __name__ == '__main__':
-    print __doc__, "\n", model
-    print "\nNOTE: This model code is designed to be imported and programatically " \
-        "manipulated,\nnot executed directly. The above output is merely a " \
-        "diagnostic aid."
+    print(__doc__, "\n", model)
+    print("""
+NOTE: This model code is designed to be imported and programatically
+manipulated, not executed directly. The above output is merely a
+diagnostic aid.""")
